@@ -3,6 +3,7 @@ import threading
 from .SoundSystem.SoundManager import sound_manager
 from .SoundSystem.AudioCommands import CommandListener
 from multiprocessing import Queue
+import numpy as np
 from .Models.ParallelProcessing import Worker
 
 
@@ -35,6 +36,8 @@ class drowsiness_detector(threading.Thread):
             return None
         return frame
 
+
+
     def __display_frame(self, frame):
 
         if self.__LastWorkerResult is not None:
@@ -44,12 +47,13 @@ class drowsiness_detector(threading.Thread):
                      cv2.rectangle(frame, (x, y), (x + w, y + h), (100, 100, 100), 1)
                      message = "closed" if self.__LastWorkerResult.OpenProbability == 0 else "open"
                      self.__putMessage(message, frame)
-                 else:
+            if self.__LastWorkerResult.LeftEye is None and self.__LastWorkerResult.RightEye is None:
                      self.__putMessage("Eyes not detected", frame)
         else:
             self.__putMessage("Initializing .......",frame=frame)
 
         cv2.imshow('frame', frame)
+
         # waiting for 1ms before proceeding further
         if cv2.waitKey(1) & 0xFF == ord('q'):
             return False
@@ -66,7 +70,6 @@ class drowsiness_detector(threading.Thread):
                 continue
 
             if self.__input_queue.empty():
-                print("sended frame")
                 self.__input_queue.put(frame)
 
             if not self.__result_queue.empty():
@@ -75,10 +78,12 @@ class drowsiness_detector(threading.Thread):
 
             if not self.__display_frame(frame)  or self.__Interrupt:
                 break
+
         self.__stream.release()
+        self.__MySoundManager.interrupt()
         if self.__Assistant is not None:
             self.__Assistant.stop()
-        self.__worker.kill()
+        self.__worker.terminate()
         cv2.destroyAllWindows()
 
     def quit(self):
